==> ocstore25_6_20.zip: OcStore/Prgm/data/language/en-us/script/CS_soapcastle_puuroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")RoomInit()FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")RoomInit()FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")RoomInit()FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")RoomInit()FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")RoomInit()FAI(4)
end

function RoomInit()
    LAY("fbk",true);
end

function GoSoapCastle()
    PRI()FAO(1)TRA("CS_soapcastle","E0093",22,38)
end

function Tank1()
    if(FLJ("HeroBack")) then
        PRI()
        MS3("A large opened can of red acrylic paint,")NOD()
        CAT("\nThe paint has dried up.")NOD()
    else
        PRI()
        MS3("A large open can of red paint,")NOD()
        CAT("\nthe paint is still wet,")NOD()
        CAT("\nindicating it was used just recently.")NOD()
    end
end

function IronheadDyed()
    KEY()
    ANP("Ironhead1","lie")
    ANP("Tala1","look_down")
    FAI(2)
    WAI(64)
    FAC("puu_normal")MS3("\nLet's begin then.")NOD()CLR()
    FAC("soapwalker_normal")CAT("\nAlright!")NOD()CLO()
    WAI(16)
    ANP("Puu1","back")
    ANP("Tala1","back")
    WAI(32)
    ANP("Ironhead1","struggle")
    WAI(64)
    ANP("Ironhead1","lie")
    WAI(64)
    ANP("Puu1","show_brush")
    ANP("Ironhead1","lie_dyed")
    WAI(32)
    ANP("Ironhead1","struggle_dyed")
    WAI(32)
    FAC("puu_dyed_normal")MS3("Stop moving, you stupid fish!")NOD()
    CAT("\nYou got paint all over my face!!")NOD()CLO()
    FAO(0)
    TRA("CS_soapcastle","PlayedIronDyedAniEnd",22,38)
end

function TheKingIsComeBack()
    KEY()
    LAY("fbk",true);
    ANP("Ironhead1","red_lie")
    ANP("Puu1","back")
    ANP("Puu1","show_brush")
    ANP("Tala1","back")
    FAI(2)
    WAI(64)
    SOU("CS_026_quake")QUA(16)
    WAI(16)
    ANP("Puu1","normal")
    WAI(16)
    ANP("Tala1","normal")
    WAI(16)
    FAC("puu_normal")MS3("Oh no!")
    CAT("\nIt's the signal from the") 
    CAT("\ntroll brothers.")NOD()CLR()
    CAT("\n\"The King is back!\"")NOD()CLR()
    ANP("Tala1","look_down")
    FAC("soapwalker_normal")CAT("What are you going to do now?")NOD()
    CAT("\nEven though it's waterproof paint,")NOD()
    CAT("\nit's not dry yet.")NOD()
    CAT("\nIf we throw him back into the pool")
    CAT("\nit might turn into a blood pool...")NOD()CLR()
    ANP("Puu1","normal",1)
    FAC("puu_normal")CAT("I'll go stall the King,")NOD()
    CAT("\nthe rest is up to you!")NOD()CLO()
    ANP("Puu1","leave")
    WAI(32)
    ANP("Tala1","look_normal")
    WAI(16)
    ANP("Tala1","look_up")
    WAI(32)
    ANP("Tala1","look_top")
    WAI(16)
    FAC("soapwalker_angry")MS3("\nHey! Don't dump everything on me!")NOD()CLO()
    WAI(64)
    ANP("Tala1","look_down")
    WAI(64)
    ANP("Tala1","back")
    WAI(32)
    MS3("I guess I'll have to take the fish") 
    CAT("\nto my room and figure something out...")NOD()CLO()
    WAI(16)
    FAO(0)
    TRA("CS_soapcastle_talaroom","DryIronhead",21,15)
end

==> ocstore25_7_23.zip: OcStore/Prgm/data/language/en-us/script/CS_soapcastle_puuroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")RoomInit()FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")RoomInit()FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")RoomInit()FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")RoomInit()FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")RoomInit()FAI(4)
end

function RoomInit()
    LAY("fbk",true);
end

function GoSoapCastle()
    PRI()FAO(1)TRA("CS_soapcastle","E0093",22,38)
end

function Tank1()
    if(FLJ("HeroBack")) then
        PRI()
        MS3("A large opened can of red acrylic paint,")NOD()
        CAT("\nThe paint has dried up.")NOD()
    else
        PRI()
        MS3("A large open can of red paint,")NOD()
        CAT("\nthe paint is still wet,")NOD()
        CAT("\nindicating it was used just recently.")NOD()
    end
end

function IronheadDyed()
    KEY()
    ANP("Ironhead1","lie")
    ANP("Tala1","look_down")
    FAI(2)
    WAI(64)
    FAC("puu_normal")MS3("\nLet's begin then.")NOD()CLR()
    FAC("soapwalker_normal")CAT("\nAlright!")NOD()CLO()
    WAI(16)
    ANP("Puu1","back")
    ANP("Tala1","back")
    WAI(32)
    ANP("Ironhead1","struggle")
    WAI(64)
    ANP("Ironhead1","lie")
    WAI(64)
    ANP("Puu1","show_brush")
    ANP("Ironhead1","lie_dyed")
    WAI(32)
    ANP("Ironhead1","struggle_dyed")
    WAI(32)
    FAC("puu_dyed_normal")MS3("Stop moving, you stupid fish!")NOD()
    CAT("\nYou got paint all over my face!!")NOD()CLO()
    FAO(0)
    TRA("CS_soapcastle","PlayedIronDyedAniEnd",22,38)
end

function TheKingIsComeBack()
    KEY()
    LAY("fbk",true);
    ANP("Ironhead1","red_lie")
    ANP("Puu1","back")
    ANP("Puu1","show_brush")
    ANP("Tala1","back")
    FAI(2)
    WAI(64)
    SOU("CS_026_quake")QUA(16)
    WAI(16)
    ANP("Puu1","normal")
    WAI(16)
    ANP("Tala1","normal")
    WAI(16)
    FAC("puu_normal")MS3("Oh no!")
    CAT("\nIt's the signal from the") 
    CAT("\ngolem brothers.")NOD()CLR()
    CAT("\n\"His Majesty is back!\"")NOD()CLR()
    ANP("Tala1","look_down")
    FAC("soapwalker_normal")CAT("What are you going to do now?")NOD()
    CAT("\nEven though it's waterproof paint,")NOD()
    CAT("\nit's not dry yet.")NOD()
    CAT("\nIf we throw him back into the pool")
    CAT("\nit might turn into a blood pool...")NOD()CLR()
    ANP("Puu1","normal",1)
    FAC("puu_normal")CAT("I'll go stall His Majesty,")NOD()
    CAT("\nthe rest is up to you!")NOD()CLO()
    ANP("Puu1","leave")
    WAI(32)
    ANP("Tala1","look_normal")
    WAI(16)
    ANP("Tala1","look_up")
    WAI(32)
    ANP("Tala1","look_top")
    WAI(16)
    FAC("soapwalker_angry")MS3("\nHey! Don't dump everything on me!")NOD()CLO()
    WAI(64)
    ANP("Tala1","look_down")
    WAI(64)
    ANP("Tala1","back")
    WAI(32)
    MS3("I guess I'll have to take the fish") 
    CAT("\nto my room and figure something out...")NOD()CLO()
    WAI(16)
    FAO(0)
    TRA("CS_soapcastle_talaroom","DryIronhead",21,15)
end
